This crate contains kube-rs compatible bindings for Kubernetes custom resources for the tf.tungsten.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
tf.tungsten.io/v1alpha1
AnalyticsAnalyticsAlarmAnalyticsSnmpCassandraConfigControlKubemanagerManagerQueryEngineRabbitmqRedisVrouterWebuiZookeeper